pub fn parse_program_with_file_id( source: &str, file_id: FileId, ) -> Result<Program, Diagnostic>
Parse a full Amarok program and stamp every span with the given FileId.
FileId
Returns an error if the source is not valid Amarok syntax for a full program. Errors are reported with the given file_id attached to their span.
file_id